///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
//! \file   ExportDlg.h
//! \brief  Defines the mgExportDlg class.
//!
//! See ExportDlg.cpp for more info.
///////////////////////////////////////////////////////////////////////


#ifndef EXPORTDLG_H
#define EXPORTDLG_H

// optimization for GCC compiler
#ifdef __GNUG__
#pragma interface "ExportDlg.h"
#endif

// required because export dlg is able to integrate
// both with mgMathBox and with mgMathWnd...
#include "mg/MathBoxWndUser.h"




///////////// CONDITIONAL COMPILATION

// these are some defines used to compile out some portions of code
//#define CEXPDLG_STILL_NOT_WORKING
#define CEXPDLG_USE_BOLD_FONT



// radio button & groups
#define IDC_EXPDLG_XML					mgEXPDLG_BASEID+1
#define IDC_EXPDLG_XHTML				mgEXPDLG_BASEID+2

// choices
#define IDC_EXPDLG_BROWSER_LIST			mgEXPDLG_BASEID+3
#define IDC_EXPDLG_IE					mgEXPDLG_BASEID+4
#define IDC_EXPDLG_MOZILLA				mgEXPDLG_BASEID+5

#define IDC_EXPDLG_EVERYTHING			mgEXPDLG_BASEID+6
#define IDC_EXPDLG_SELECTION			mgEXPDLG_BASEID+7

// checkboxes
#define IDC_EXPDLG_USE_NS				mgEXPDLG_BASEID+8
#define IDC_EXPDLG_UPPER				mgEXPDLG_BASEID+9
#define IDC_EXPDLG_MATH_PLAYER			mgEXPDLG_BASEID+10

// textctrls
#define IDC_EXPDLG_INDENTATION			mgEXPDLG_BASEID+11
#define IDC_EXPDLG_NS					mgEXPDLG_BASEID+12
#define IDC_EXPDLG_PREVIEW				mgEXPDLG_BASEID+13
#define IDC_EXPDLG_FILE					mgEXPDLG_BASEID+14
#define IDC_EXPDLG_TITLE				mgEXPDLG_BASEID+15

// buttons
#define IDC_EXPDLG_EXPORT_AND_OPEN		mgEXPDLG_BASEID+16
#define IDC_EXPDLG_EXPORT				mgEXPDLG_BASEID+17
#define IDC_EXPDLG_BROWSE				mgEXPDLG_BASEID+18
#define IDC_EXPDLG_SHOWADV				mgEXPDLG_BASEID+19


// these will be defined later...
class mgExportDlg;
class mgExportAdvOpt;


//! Base class for the panels containing the BASIC and the ADVANCED
//! options which are shown in the mgExportDlg.
class mgExportBasePanel : public wxPanel
{
protected:

	//! Initializes the controls whose pointers are stored in the
	//! member variables to be easily used when required.
	//! In this way, we do not have to use wxWindow::FindWindowById
	//! each time we must access them. Please note that IDs are still 
	//! required for event handling.
	virtual void BuildCtrls() = 0;

public:
	mgExportBasePanel(wxWindow* parent, wxWindowID id = -1)
		: wxPanel(parent, id) {}
	virtual ~mgExportBasePanel() {}


	//! Creates everything regarding this panel.
	//! This function calls #BuildCtrls() and then creates the
	//! entire layout for this panel.
	virtual void BuildAll() = 0;

private:
	DECLARE_ABSTRACT_CLASS(mgExportBasePanel)
};



//! A panel composed of a wxStaticBoxSizer containing various
//! widgets which allow the user to modify the basic export
//! options. The basic options are:
//! - choice of preset advanced options to optimize exported
//!   file for a specific browser
//! - title of the exported file
//! - name and path of the exported file (which can be chosen
//!   using a wxFileDialog)
//! 
//! This class can be used as a base class for a different
//! panel of basic options. In this case the derived class must
//! overload the functions whose behaviour must be changed;
//! to force the creation of derived-class instead of 
//! mgExportBasicOpt, a mgExportDlg's derived class must be created
//! with an overloaded mgExportDlg::BuildCtrls() function (which 
//! is the place where mgExportBasicOpt is created).
class mgExportBasicOpt : public mgExportBasePanel
{
	friend class mgExportDlg;
	friend class mgExportAdvOpt;

protected:		// member variables

	//! The preset browser compability modes.
	wxChoice *m_pChoice;

	//! The destination of the exported file.
	wxTextCtrl *m_pDest;

	//! The title of the exported file.
	wxTextCtrl *m_pTitle;

	//! This button allows the user to show/hide the ADVANCED
	//! panel eventually linked to this class. If there is
	//! no advanced panel linked to this class, this button
	//! is hidden.
	wxButton *m_pShowAdv;

	//! Instance of the file chooser dialog which can be
	//! used to change #m_pDest.
	wxFileDialog *m_pFD;

	//! The ADVANCED panel which is linked to this class. 
	//! If there is no ADVANCED panel linked to this class
	//! (that is, if this pointer is NULL), the #m_pShowAdv
	//! button is hidden.
	mgExportAdvOpt *m_pAdv;


protected:		// functions

	//! \name Event handlers. @{
	void OnShowAdv( wxCommandEvent &event );
	void OnBrowserModeChanged( wxCommandEvent &event );
	void OnTitleChanged( wxCommandEvent &event );
	void OnBrowse( wxCommandEvent &event );
	//@}

	//! Returns the label which should be currently shown on the
	//! "Show advanced options" button.
	virtual wxString GetShowAdvLabel();

	virtual void BuildCtrls();

public:

	//! Creates the panel but does not create the controls which are
	//! contained; see #BuildAll() if you want to build them.
	//! \param parent The parent window (it should be mgExportDlg or
	//!        a mgExportDlg-derived class).
	//! \param adv The advanced panel linked to this panel; if this
	//!        pointer is NULL, the "Show advanced options" is
	//!        hidden.
	//! \param id The ID of this panel.
	mgExportBasicOpt(wxWindow* parent, 
		mgExportAdvOpt *adv = NULL, 
		wxWindowID id = -1)
		: mgExportBasePanel(parent, id), m_pAdv(adv) {}

	virtual ~mgExportBasicOpt() {
		// delete all windows not managed by sizers
		if (m_pFD) delete m_pFD;
	}


	//! Links this panel with an advanced panel.
	//! If the given pointer is NULL, the #m_pShowAdv button is
	//! automatically hidden.
	void SetAdvPanel(mgExportAdvOpt *adv) {
		m_pAdv = adv;
	}

	virtual void BuildAll();

private:
	DECLARE_CLASS(mgExportBasicOpt)
	DECLARE_EVENT_TABLE()
};




//! This is the panel which allows the user to modify some ADVANCED
//! options regarding MathML export process.
//! This panel contains an useful preview box which shows (in read
//! only mode) what will be exported.
//! The options which can be set through this panel are:
//! - exported file type (XML or XHTML)
//! - export range (selection or entire content of the linked mgMathBox)
//! - MathPlayer support
//! - case of exported tags (lowercase or uppercase)
//! - namespace presence and namespace label
//!
//! As for mgExportBasicOpt, this panel can be used as base class for
//! a different advanced options panel... see mgExportBasicOpt
//! description.
class mgExportAdvOpt : public mgExportBasePanel
{
	friend class mgExportDlg;
	friend class mgExportBasicOpt;

protected:		// member variables

	/////////////////////////////////////////////////////////////////////
	//! \name Control pointers
	//! Pointers to the controls used in the dialog. @{
	wxCheckBox *m_pUseNS, *m_pUpper, *m_pMathPlayer;
	wxTextCtrl *m_pNS, *m_pIndentation, *m_pPreview;	
	wxRadioButton *m_pXHTML, *m_pXML;

	//@}

	//! The BASIC options panel which is linked to this class.
	mgExportBasicOpt *m_pBasic;

	//! The mgMathBox which is used to retrieve export preview.
	mgMathBox *m_pBox;

	//! The path to the XSL data which is used for .
	wxString m_strXSLPath;

	//! If TRUE, the "Tag preview" box is enabled.
	bool m_bPreviewEnabled;


protected:		// functions

	//! \name Event handlers. @{
	void OnUseNS( wxCommandEvent &event );
	void OnPreviewChanged( wxCommandEvent &event );
	void OnTypeChanged( wxCommandEvent &event );
	void OnMathPlayer( wxCommandEvent &event );
	//@}

	virtual void BuildCtrls();

public:

	//! Constructs the panel; call #BuildAll() to complete creation.
	//! \param parent The parent window (it should be mgExportDlg).
	//! \param basic The basic options panel which is used to retrieve
	//!        the informations used to build the export preview.
	//! \param box The mgMathBox which is used to retrieve export
	//!        preview; see mgMathBox::GetExportPreview.
	//! \param xslpath The path to the XSL files used when exporting
	//!        a pure XML file.
	mgExportAdvOpt(wxWindow* parent, mgExportBasicOpt *basic = NULL, 
		mgMathBox *box = NULL, const wxString &xslpath = wxEmptyString,
		wxWindowID id = -1)
		: mgExportBasePanel(parent, id), m_pBasic(basic), 
		m_pBox(box), m_strXSLPath(xslpath) {
		m_bPreviewEnabled = FALSE;
	}

	virtual ~mgExportAdvOpt() {}


	//! Enables/disables the preview of MathML tags.
	virtual void EnablePreview(bool enable = TRUE) {
		m_bPreviewEnabled = enable;
	}

	//! Reads the indentation value from m_pIndentation, converts it to
	//! a number and returns it.
	int GetIndentation();

	virtual void BuildAll();

private:
	DECLARE_CLASS(mgExportAdvOpt)
	DECLARE_EVENT_TABLE()
};




//! Shows the user a dialog which allows him to choose MathML export
//! options. The dialog contains two main elements, the BASIC & the
//! ADVANCED options panels, plus the three wxT("action buttons"): "Export", 
//! wxT("Export and open in default browser"), "Cancel".
//! 
//! If the user of MathGUI wants to modify this dialog, it should derive
//! a new class from mgExportDlg and override the functions he wants;
//! specially #BuildCtrls() which create the two main option panels.
class mgExportDlg : public wxDialog, public mgMathBoxWndUser
{
protected:		// member variables

	/////////////////////////////////////////////////////////////////////
	//! \name Control pointers
	//! Pointers to the controls used in the dialog: they are used
	//! to retrieve the informations about export options when the
	//! user clicks one of the theree main buttons... @{

	wxFont m_fBoldFont;
	wxSizer *m_pMainPanel, *m_pButtonsPanel;

	mgExportBasicOpt *m_pBasicOptPanel;
	mgExportAdvOpt *m_pAdvOptPanel;

	//@}


	//! The HREF used to link XSL required files when exporting data as pure XML file.
	wxString m_strXSLPath;


	//! Used by some functions to check if all
	//! controls (and their pointers) can be used.
	bool m_bBuildComplete;

	//! If TRUE the panel of advanced options is currently visible.
	bool m_bShowAdv;


protected:		// functions

	// button event handlers
	void OnExport( wxCommandEvent &event );
	void OnExportAndOpen( wxCommandEvent &event );
	
	//! Creates all the controls of the dialog.
	virtual void BuildAll();

	//! Creates the sizer with the three main buttons of the dialog.
	virtual wxSizer *BuildButtons();

	//! Creates the two mgExportBasePanel-derived panels contained
	//! in this dialog and then init them calling their
	//! mgExportBasePanel::BuildAll() functions.
	virtual void BuildCtrls();

public:

	//! Constructs this dialog. See mgMathBoxWndUser for the
	//! meaning of the \c mathwnd and \c mathbox parameters.
	mgExportDlg(wxWindow *parent,
		mgMathWnd *mathwnd,
		mgMathBox *mathbox,
		const wxString &href,
		wxWindowID id = -1, 
		const wxString &title = wxT("Export options"),
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER);

	virtual ~mgExportDlg();
	

	//! Returns a pointer to the BASIC option panel of this dialog.
	virtual mgExportBasicOpt *GetBasicOpt() {
		return m_pBasicOptPanel;
	}

	//! Returns a pointer to the ADVANCED option panel of this dialog.
	virtual mgExportAdvOpt *GetAdvOpt() {
		return m_pAdvOptPanel;
	}

	//! Returns TRUE if the ADVANCED option panel is currently visible.
	virtual bool isShowingAdvOpt() {
		return m_bShowAdv;
	}

	//! Shows the ADVANCED options panel if it is currently hidden;
	//! hides it if it currently visible. 
	//! This function resizes the dialog and center it in the screen.
	virtual void ShowAdv();
		
private:
	DECLARE_CLASS(mgExportDlg)
	DECLARE_EVENT_TABLE()
};


#endif	// EXPORTDLG_H

