///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
//! \file   ImportDlg.h
//! \brief  Defines the mgImportDlg class.
//!
//! See ImportDlg.cpp for more info.
///////////////////////////////////////////////////////////////////////


#ifndef IMPORTDLG_H
#define IMPORTDLG_H

// optimization for GCC compiler
#ifdef __GNUG__
#pragma interface "ImportDlg.h"
#endif

// required because import dlg is able to integrate both
// with mgMathWnd and with mgMathBox
#include "mg/MathBoxWndUser.h"


// buttons
#define IDC_IMPORTDLG_IMPORT_BTN			mgIMPDLG_BASEID+1

// radio buttons
#define IDC_IMPORTDLG_INLINEDEXPR			mgIMPDLG_BASEID+2
#define IDC_IMPORTDLG_MATHML				mgIMPDLG_BASEID+3

// text controls
#define IDC_IMPORTDLG_INLINEDEXPR_FIELD		mgIMPDLG_BASEID+4



//! Shows the user a dialog which allows him to choose MathML export
//! options. The dialog contains two main elements: the BASIC & the
//! ADVANCED options.
class mgImportDlg : public wxDialog, public mgMathBoxWndUser
{
protected:		// member variables

	//! The text control where inlined expressions ca be pasted.
	wxTextCtrl *m_pExpr;

	//! The file dialog which allows the user to choose the MathML
	//! file to import...
	wxFileDialog *m_pFD;


protected:		// functions

	//! Creates all the controls of the dialog.
	void BuildAll();

	//! Creates all the controls whose pointers are stored in member
	//! variables to allow fast access to them.
	void BuildCtrls();

	// event handlers
	void OnImport(wxCommandEvent &ev);
	void OnInlinedExprChange(wxCommandEvent &ev);

public:

	//! Constructs this dialog.
	mgImportDlg(wxWindow *parent,
		mgMathWnd *wnd, 
		mgMathBox *box,
		wxWindowID id = -1, 
		const wxString &title = wxT("Import options"),
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER);

	virtual ~mgImportDlg();
	

	//! Returns TRUE if the user has chosen to import a MathML file.
	bool isImportingMathML();

	//! Returns TRUE if the user has chosen to import an inlined expression.
	bool isImportingInlinedExpr() {
		return !isImportingMathML();
	}

		
private:
	DECLARE_EVENT_TABLE()
};


#endif	// IMPORTDLG_H
