///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
//! \file   MathBoxWndUser.h
//! \brief  Defines the mgMathBoxWndUser class.
//!
//! See MathBoxWndUser.cpp for more info
///////////////////////////////////////////////////////////////////////


#ifndef MATHBOXWNDUSER_H
#define MATHBOXWNDUSER_H

// required
#include "mg/MathWnd.h"
#include "mg/MathBox.h"


// optimization for GCC compiler
#ifdef __GNUG__
#pragma interface "MathBoxWndUser.h"
#endif


//! A little class which allow derived-classes to handle a single,
//! fixed mgMathBox or the selected box inside a mgMathWnd, in a 
//! completely transparent way.
//! Derived classes should, in fact, just use the #GetBox() function:
//! mgMathBoxWndUser will provide a working pointer.
class mgMathBoxWndUser
{
protected:

	//! The math window where all the commands are sent.
	//! Commands are sent to this \c mgMathWnd only if it is not
	//! NULL. See the ctor for more details.	
	mgMathWnd *m_pMathWnd;

	//! The math box where all the commands are sent.
	//! This variable is used only if m_pMath is NULL.
	mgMathBox *m_pMathBox;

	//! Returns TRUE if this class has been linked with a mgMathWnd, FALSE if
	//! has been linked with a mgMathBox (see the constructors).
	bool isUsingMathWnd();

	//! Returns the box where the commands must be sent.
	//! This function checks which pointer is not NULL: 
	//! m_pMath or m_pBox, and then use it to return a 
	//! safe pointer to the mgMathBox which must receive commands.
	mgMathBox *GetBox();

	//! Returns the pointer to the eventually previously set mgMathWnd.
	//! The returned value can be NULL (if no mgMathWnd are being used).
	mgMathWnd *GetWnd() { return m_pMathWnd; }


public:

	//! The constructor: derived classes should always contain among the
	//! parameters of their constructors the two parameters to pass to
	//! this function: \c pBox and \c pWnd.
	//! If you want to use a fixed mgMathBox, pass a non-null pointer as
	//! \c pBox and a null pointer as \c pWnd, and viceversa.
	mgMathBoxWndUser(mgMathWnd *pWnd, mgMathBox *pBox) {
		m_pMathWnd = pWnd;
		m_pMathBox = pBox;
	}


	// some utility functions
	
	//! Sets appropriately the ID, event type and the originating 
	//! object fields of the given wxKeyEvent class and then sends
	//! it to the client box.
	//! \param p The wxWidgets object which origins the event
	//! \param ev The event to send.
	void SendKeyEvent(wxObject *p, wxKeyEvent &ev);
	void SendKeyEvent(wxObject *p, wxChar c);
	void SendSpecialKeyEvent(wxObject *p, wxKeyEvent &ev);
	void SendSpecialKeyEvent(wxObject *p, wxChar c);
};

#endif		// MATHBOXWNDUSER_H


