///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
//! \file   MathGUI.h
//! \brief  Defines the mgMathGUI class.
//!
//! See MathGUI.cpp for more info.
///////////////////////////////////////////////////////////////////////



#ifndef MATHGUI_H
#define MATHGUI_H


// For compilers that support precompilation, the file wxprec.h
// will include the precompiled "wx.h" header file.
#include <wx/wxprec.h>

#ifndef WX_PRECOMP
// If precompilation is not supported, include your minimal 
// set of headers here, or wx.h
#include <wx/wx.h>
#endif


// this is part of MathCore library which is required to use
// the MathGUI library....
class mcMathCore;


BEGIN_DECLARE_EVENT_TYPES()
	DECLARE_EVENT_TYPE( mgEVT_SYNTAX_ERROR, mgMATHGUI_GENERAL_EVENTS_BASEID )
END_DECLARE_EVENT_TYPES()


//! Adds an event handler for the mgEVT_ACTIVE_ELEM_CHANGED custom event:
//! the wxEvtHandler registered as client event handler of the mgMathBox
//! window will receive such an event each time the element highlighted
//! by mouse cursor changes.
#define EVT_SYNTAX_ERROR(winid, fn)									\
	DECLARE_EVENT_TABLE_ENTRY( mgEVT_SYNTAX_ERROR, winid,			\
		wxID_ANY, (wxObjectEventFunction) (wxEventFunction)			\
		wxStaticCastEvent( wxCommandEventFunction, & fn ),			\
		(wxObject *) NULL ),




//! The mgMathGUI class: this static class contains global variables,
//! functions and defines used by almost all MathGUI classes.
//! This is a singleton class: access it using the #Get() function:
//!
//! \begincode
//! mcMathGUI::Get()->DoWhatIWant();
//! \endcode
//!
class mgMathGUI
{

protected:

	//! The global instance of the class shared everywhere in programs
	//! which use this library.
	static mgMathGUI *g_pTheInstance;

	//! The base configuration string used by the library to store
	//! the customizable settings into the wxConfig object given to
	//! mgMathGUI::Setup.
	wxString m_strBaseConfigPath;

	//! The pointer to the mcMathCore instance which is handled by
	//! this library.
	mcMathCore *m_pCore;

	//! A pointer to the application using this library.
	static wxApp *m_pApp;

public:

	mgMathGUI();
	virtual ~mgMathGUI();


	//! Handles the MathCore syntax errors sending a mgEVT_SYNTAX_ERROR
	//! error to the application object given to #Setup().
	static void OnError(const wxString &);


	//! Returns the global instance of mgMathGUI.
	static mgMathGUI *Get();

	//! Sets the global instance of mgMathGUI.
	static void Set(mgMathGUI *);


	//! Sets up the global instance of mgMathGUI.
	static void Setup(wxApp *);

	//! Cleans up the global instance of mgMathGUI.
	static void Cleanup();
};


#endif	// MATHGUI_H


