///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
//! \file   MathMenu.h
//! \brief  Defines the mgMathMenu class.
//!
//! See MathMenu.cpp for more info
///////////////////////////////////////////////////////////////////////


#ifndef MATHMENU_H
#define MATHMENU_H

// with this little class (mgMathBoxWndUser), we can create a 
// mgMathMenu able to send commands both to a single, fixed mgMathBox 
// or the mgMathBox which is the active one in a mgMathWnd
#include "mg/MathBoxWndUser.h"
#include "mg/GreekDlg.h"
#include "mg/SpecialSymDlg.h"
#include "mg/SymbolDlg.h"

// this class uses mgOptKeyBindingsPanel
#include "mg/OptKeyBindings.h"

// wxFileName is required
#include <wx/filename.h>

// optimization for GCC compiler
#ifdef __GNUG__
#pragma interface "MathMenu.h"
#endif


// IDs used in this dialog
#define MATHMENU_FILE_BASEID						mgMATHMENU_BASEID
#define MATHMENU_EDIT_BASEID						mgMATHMENU_BASEID+20
#define MATHMENU_MATH_BASEID						mgMATHMENU_BASEID+40
#define MATHMENU_VIEW_BASEID						mgMATHMENU_BASEID+60
#define MATHMENU_HELP_BASEID						mgMATHMENU_BASEID+80

// file commands
#define IDM_MATHMENU_FILE_IMPORT					MATHMENU_FILE_BASEID+1
#define IDM_MATHMENU_FILE_EXPORT_ASXHTML			MATHMENU_FILE_BASEID+2
#define IDM_MATHMENU_FILE_EXPORT_ASIMAGE			MATHMENU_FILE_BASEID+3

// edit commands
#define IDM_MATHMENU_EDIT_CUT						MATHMENU_EDIT_BASEID+1
#define IDM_MATHMENU_EDIT_COPY						MATHMENU_EDIT_BASEID+2
#define IDM_MATHMENU_EDIT_PASTE						MATHMENU_EDIT_BASEID+3

#define IDM_MATHMENU_EDIT_EDIT_EXP					MATHMENU_EDIT_BASEID+4
#define IDM_MATHMENU_EDIT_EDIT_SUBSCRIPT			MATHMENU_EDIT_BASEID+5
#define IDM_MATHMENU_EDIT_INSERT_FRACTION 			MATHMENU_EDIT_BASEID+6
#define IDM_MATHMENU_EDIT_INSERT_RADICAL			MATHMENU_EDIT_BASEID+7
#define IDM_MATHMENU_EDIT_INSERT_FUNCTION			MATHMENU_EDIT_BASEID+8
#define IDM_MATHMENU_EDIT_INSERT_SPECIAL			MATHMENU_EDIT_BASEID+9
#define IDM_MATHMENU_EDIT_BOXES						MATHMENU_EDIT_BASEID+10
#define IDM_MATHMENU_EDIT_SYSTEM					MATHMENU_EDIT_BASEID+11

#define IDM_MATHMENU_EDIT_NEWBOX					MATHMENU_EDIT_BASEID+12
#define IDM_MATHMENU_EDIT_NEWTEXTBOX				MATHMENU_EDIT_BASEID+13
#define IDM_MATHMENU_EDIT_NEWBOX_LIKELAST			MATHMENU_EDIT_BASEID+14
#define IDM_MATHMENU_EDIT_DELETEBOX 				MATHMENU_EDIT_BASEID+15
#define IDM_MATHMENU_EDIT_NEWMATHLINE				MATHMENU_EDIT_BASEID+16
#define IDM_MATHMENU_EDIT_NEWMATHLINE_LIKELAST		MATHMENU_EDIT_BASEID+17
#define IDM_MATHMENU_EDIT_DELETEMATHLINE			MATHMENU_EDIT_BASEID+18

#define IDM_MATHMENU_EDIT_OPTIONS 					MATHMENU_EDIT_BASEID+19

// math commands
#define IDM_MATHMENU_MATH 							MATHMENU_MATH_BASEID+1
#define IDM_MATHMENU_MATH_MULTIPLY					MATHMENU_MATH_BASEID+2
#define IDM_MATHMENU_MATH_DIVIDE					MATHMENU_MATH_BASEID+3
#define IDM_MATHMENU_MATH_MOVE						MATHMENU_MATH_BASEID+4
#define IDM_MATHMENU_MATH_RAISE						MATHMENU_MATH_BASEID+5
#define IDM_MATHMENU_MATH_EXPAND					MATHMENU_MATH_BASEID+6
#define IDM_MATHMENU_MATH_SIMPLIFY					MATHMENU_MATH_BASEID+7
#define IDM_MATHMENU_MATH_EVALUATE					MATHMENU_MATH_BASEID+8
#define IDM_MATHMENU_MATH_SOLVE						MATHMENU_MATH_BASEID+9


// view commands
#define IDM_MATHMENU_VIEW 							MATHMENU_VIEW_BASEID+1
#define IDM_MATHMENU_VIEW_PALETTES 					MATHMENU_VIEW_BASEID+2
#define IDM_MATHMENU_VIEW_PALETTE_GREEK_ALPHABET	MATHMENU_VIEW_BASEID+3
#define IDM_MATHMENU_VIEW_PALETTE_SPECIAL_SYMBOLS	MATHMENU_VIEW_BASEID+4
#define IDM_MATHMENU_VIEW_PALETTE_SYMBOLS			MATHMENU_VIEW_BASEID+5
#define IDM_MATHMENU_VIEW_DESCRIPTION 				MATHMENU_VIEW_BASEID+7
#define IDM_MATHMENU_VIEW_ALIGN_LEFT				MATHMENU_VIEW_BASEID+8
#define IDM_MATHMENU_VIEW_ALIGN_CENTER				MATHMENU_VIEW_BASEID+9
#define IDM_MATHMENU_VIEW_ALIGN_RIGHT 				MATHMENU_VIEW_BASEID+10

// help commands
#define IDM_MATHMENU_HELP 							MATHMENU_HELP_BASEID+1
#define IDM_MATHMENU_HELP_MAIN						MATHMENU_HELP_BASEID+2
#define IDM_MATHMENU_HELP_HOME_PAGE					MATHMENU_HELP_BASEID+3
#define IDM_MATHMENU_HELP_PROJECT_PAGE				MATHMENU_HELP_BASEID+4
#define IDM_MATHMENU_HELP_WISH_LIST					MATHMENU_HELP_BASEID+5
#define IDM_MATHMENU_HELP_BUG_LIST					MATHMENU_HELP_BASEID+6
#define IDM_MATHMENU_HELP_ABOUT						MATHMENU_HELP_BASEID+7



//! \class mgMathMenu
//! \brief Implements the menu and the menu handlers for default menus.
//!
//! This class contains some functions used to add the default MathGUI
//! menu items to a mathematical application.
//! The class, derived from wxEvtHandler, implements also the default
//! event handlers for the menu items.
//! You are not required to use this class at all but, if you do not
//! use it, you have to define menu items and menu event handlers
//! yourself.
//!
//! To use this class, you simply have to construct in your
//! frame costructor a wxMenu object and then use the \cAppendXxxxx
//! functions to add items in the menu.
//! You can also add other menu items in the popup menu.
//!
//! \code
//!      wxMenuBar *menuBar = new wxMenuBar();
//!      mgMathMenu *standardMenu = new mgMathMenu( childWnd, this );
//!      wxMenu *edit = new wxMenu();
//!      standardMenu->AppendEditCommands( edit );
//!      menuBar->Append( edit, "Edit" );
//! \endcode
//! 
//! You do not have to worry about handling events for the
//! menu items appended by the mgMathMenu class because it is
//! mgMathMenu's responsability to handle them.
//! 
//! In the constructor of mgMathMenu you have to pass two parameters:
//! 
//! \li a mgMathWnd pointer that represent the container window of the
//! math expressions to which command events are to be applicated
//! \li a wxFrame pointer representing the frame window which
//! command menu events are handled by this class.
//! 
//! If you want to handle yourself all command menu events simply
//! pass a NULL pointer as the second parameter of the mgMathMenu
//! constructor:
//! 
//! \code
//!    mgMathMenu *standardMenu = new mgMathMenu( childWnd, NULL );
//! \endcode
//! 
//! This prevents mgMathMenu to be set as the event handlers for
//! the frame which pointer is passed as parameter to the ctor.
//! 
//! If you want to let mgMathMenu handle most of the standard menu
//! command events but not all of them, derive a custom class from
//! mgMathMenu and implement a EVENT_TABLE in which you declare
//! only those events in which you are interested:
//! \code
//!    class MyMathMenu : public mgMathMenu
//!    {
//!    public:
//!    	   MyMathMenu( mgMathBox* box, wxFrame* frame )
//!    		   : mgMathMenu( box, frame ) { ... }
//!   
//!    	   DECLARE_EVENT_TABLE()
//!    };
//! \endcode
//! 
//! In the \e .cpp file define the events in which you are
//! interested using the usual wxWindow's macros.
class mgMathMenu : public wxEvtHandler,			// wxEvtHandler MUST be the first (see wxWidget's wxEvtHandler docs)
					public mgMathBoxWndUser
{
	//! Optional frame.
	wxFrame *m_pFrame;

	//! Optional application object which will receive OptionsDlg
	//! notification events. If NULL, event notification by
	//! the dialog is disabled.
	wxApp *m_pTheApp;

	//! Optional logger window.
	wxLog *m_pLogger;

	//! The wxPaletteFrames to show/hide.
	wxPaletteFrame *m_pGreekAlphabet, *m_pSpecialSym, *m_pSym;

	//! The HTML file which will be opened when the user
	//! choose the "MathStudio help" menu command.
	wxString m_strHelpPath;

public:

	//! The constructor.
	//! \param pwnd The client mgMathWnd (choose this _or_ pbox)
	//! \param pbox The client mgMathBox
	//! \param pframe The frame window where the menu events are sent
	//! \param app The application object
	//! \param plogger The log window
	mgMathMenu(mgMathWnd *pwnd, mgMathBox *pbox = NULL, 
		wxFrame *pframe = NULL, wxApp *app = NULL, 
		wxLog *plogger = NULL);
	virtual ~mgMathMenu();


	// Setters
	void SetPalettes(mgGreekPalette *p1 = NULL, 
					mgSpecialSymPalette *p2 = NULL, 
					mgSymbolPalette *p3 = NULL) {
		m_pGreekAlphabet = p1;
		m_pSpecialSym = p2;
		m_pSym = p3;
	}

	void Attach(wxFrame *p);
	void Detach();

	//! Sets the #m_strHelpPath variable.
	//! Call this function only for a valid document which
	//! can be launched using the default system browser.
	void SetHelpMainFile(const wxString &str);



	// ----------------------------------------------
	// Append functions
	//
	// They are static, so you can use them even 
	// without actually allocating a mgMathMenu,
	// even if an instance of this is required for
	// event handling
	// ----------------------------------------------

	static void AppendFileCommands(wxMenu *file);
	static void AppendEditCommands(wxMenu *edit, bool bUsingMathWnd = FALSE);
	static void AppendMathCommands(wxMenu *math);
	static void AppendViewCommands(wxMenu *view);
	static void AppendHelpCommands(wxMenu *help);



	//! \name Event handlers
	//! These functions handle the EVT_MENU generated by the menu items
	//! added through mgMathMenu::Append****Commands() functions for the
	//! frame given to the #Attach() function. @{

	// file menu handlers
	void OnFileExportAsXHTML( wxCommandEvent &event );
	void OnFileExportAsImage( wxCommandEvent &event );
	void OnFileImport( wxCommandEvent &event );

	// edit menu handlers
	void OnEditCut( wxCommandEvent &event );
	void OnEditCopy( wxCommandEvent &event );
	void OnEditPaste( wxCommandEvent &event );
	void OnEditNewBox( wxCommandEvent &event );
	void OnEditNewTextBox( wxCommandEvent &event );
	void OnEditNewBoxLikeLast( wxCommandEvent &event );
	void OnEditDeleteBox( wxCommandEvent &event );
	void OnEditNewMathLine( wxCommandEvent &event );
	void OnEditNewMathLineLikeLast( wxCommandEvent &event );
	void OnEditDeleteMathLine( wxCommandEvent &event );
	void OnEditInsertSpecial( wxCommandEvent &event );
	void OnEditInsertRadical( wxCommandEvent &event );
	void OnEditInsertFraction( wxCommandEvent &event );
	void OnEditInsertFunction( wxCommandEvent &event );
	void OnEditEditExp( wxCommandEvent &event );
	void OnEditEditSubscript( wxCommandEvent &event );
	void OnEditOptions( wxCommandEvent &event );

	// math menu handlers
	void OnMathEvaluate( wxCommandEvent &event );
	void OnMathMove( wxCommandEvent &event );
	void OnMathExpand( wxCommandEvent &event );
	void OnMathSimplify( wxCommandEvent &event );
	void OnMathDivideBy( wxCommandEvent &event );
	void OnMathMultiplyBy( wxCommandEvent &event );
	void OnMathSolve( wxCommandEvent &event );

	// view menu handlers
	void OnViewPaletteGreekAlphabet( wxCommandEvent &event );
	void OnViewPaletteSpecialSym( wxCommandEvent &event );
	void OnViewPaletteSym( wxCommandEvent &event );

	// help menu handlers
	void OnHelpWishList( wxCommandEvent &event );
	void OnHelpBugList( wxCommandEvent &event );
	void OnHelpAbout( wxCommandEvent &event );
	void OnHelpProjectPage( wxCommandEvent &event );
	void OnHelpHomePage( wxCommandEvent &event );
	void OnHelpMain( wxCommandEvent &event );

	//@}

private:
	// used by wxWindow framework
	DECLARE_CLASS(mgMathMenu)
	DECLARE_EVENT_TABLE()
};

#endif		// MATHMENU_H

