///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
// \file  OptGeneral.h
// \brief Defines the mgOptGeneralPanel class.
//
// See OptGeneral.cpp for more info.
///////////////////////////////////////////////////////////////////////




#ifndef OPTGENERAL_H
#define OPTGENERAL_H

#if defined(__GNUG__) && !defined(__APPLE__)
#pragma interface "OptGeneral.h"
#endif

// required includes
#include "mg/OptBasePanel.h"




//! The panel containing the general options which can be customized
//! by the user:
//!
//! - mcBracketGUI::nSpaceAboveBelow, mcBracketGUI::nSpaceLeftRight
//! - mcFractionGUI::nSpaceAboveBelow, mcFractionGUI::nSpaceBetween,
//!   mcFractionGUI::nAdditionalWidth, mcFractionGUI::nAdditionalSpace
//! - mcElementGUI::pSelectionBrush, mcElementGUI::pActivationBrush
//! - mcEmptyBoxGUI::fEmptyBoxCharWidth, mcEmptyBoxGUI::fEmptyBoxCharHeight
//! - mcMathMng::nSpaceLeftRight
//! - mcMathOrSystem::nSpaceLeftRight, mcMathOrSystem::nSpaceBetween,
//!   mcMathOrSystem::nSpaceAboveBelow
//! - mcMonomialGUI::bEmptyBoxReplacing, mcMonomialGUI::bFunctionScanEnabled
//!   mcMonomialGUI::nSpaceBetween
//! - mcDivOpGUI::bUseColon
//! - mcPolynomialGUI::nSpaceBetween
//! - mcRadicalGUI::nSpaceAboveBelow, mcRadicalGUI::nSpaceLeftRight
//! - mcSymbolGUI::clrUndefSymbols
//! - mgMathBox::nCursorWidth, mgMathBox::nSpaceAround
//!
//! All the previous variables are STATIC, so this panel doesn't need
//! to own an instance of each class.
class mgOptGeneralPanel : public mgOptBasePanel
{
protected:			// member variables


protected:

	virtual mgOptDlg::mgOptChangedType
		CommitChanges( wxConfig* config );
	virtual void Setup( const wxString &itemLabel );

	//! Creates all the controls whose pointers are stored in member
	//! variables for fast access.
	void BuildCtrls();

public:
	mgOptGeneralPanel();
	virtual ~mgOptGeneralPanel() {}



private:
	DECLARE_DYNAMIC_CLASS( mgOptGeneralPanel )
	DECLARE_EVENT_TABLE()
};


#endif          // not defined OPTGENERAL_H


