///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
//! \file   OptTreeCtrl.h
//! \brief  Defines the mgOptTreeCtrlItemData and 
//!         mgOptionsTreeCtrl classes.
//!
//! See OptTreeCtrl.cpp for more info.
///////////////////////////////////////////////////////////////////////



#ifndef DIALOGS_OPTTREECTRL_H
#define DIALOGS_OPTTREECTRL_H

#if defined(__GNUG__) && !defined(__APPLE__)
  #pragma interface "OptTreeCtrl.h"
#endif

// For compilers that support precompilation, includes "wx/wx.h".
/*#include "wx/wxprec.h"

#ifdef __BORLANDC__
  #pragma hdrstop
#endif

// for all others, include the necessary headers 
#ifndef WX_PRECOMP
  #include "wx/wx.h"
#endif

*/
// mgOptionsTreeCtrl class is a special type of wxTreeCtrl
#include "wx/treectrl.h"


//! The IDs of the panels supported by mgMathGUI
enum IdOptionsPanel  {
    Id_mgOptBasePanel = 1,
		Id_mgOptGeneralPanel,
		Id_mgOptKeyBindingsPanel,
		Id_mgOptFontSettingsPanel
};


// this will defined later...
class mgOptBasePanel;



/*! \class mgOptTreeCtrlItemData
\brief The \c Edit | \c Options dialog: custom data object.

  This class holds informations about the item in the tree list control
  of the option's families.
  In particular, the informations stored in this object are:
  \li a pointer to the \c mgOptBasePanel panel window that is to be displayed
	when the user selects the treelist item
  \li a \c itemID used to create the specialized \c mgOptBasePanel -derived class
	
  \sa mgOptionsTreeCtrl mgOptDlg#CreatePanel mgOptDlg#DispalyPanel
*/
class mgOptTreeCtrlItemData : public wxTreeItemData
{
public:
	
	//! Constructor.
	/*!
	Initialize the \c m_className to the empty string and
	sets to NULL the \c m_panel pointer.
	
	  \param id The identifier for the optionwxT('s panel')s window class
	  \param className classname string. not used, should be empty string.
	*/
	
	mgOptTreeCtrlItemData( IdOptionsPanel id, const wxString *className = 0 );
	
	//! Destructor - It does nothing.
	virtual ~mgOptTreeCtrlItemData();
	

public:				// member variables

	//! The specialized panel to be shown when the item is selected.
	/*!
	If NULL, the panel is not yet been created and it should be instantiated
	before using it. This allows to only create the option's panels on request
	when the user clicks on a treelist item and not in the constructor of the
	dialog: we have to save time (and RAM, too!).
	\sa mgOptDlg#CreatePanel
	*/
	mgOptBasePanel*    m_panel;
	
	//! The class name of the specialized option's panel.
	/*!
    This is not used and initialized to an empty string.
    I used this for implementing the dynamical instantiation of the
    panelwxT('s window class using the wxWindow')s special RTTI feature.
    But this does not work on every platforms so I decided not to
    use it.
	*/
	wxString      m_className;
	
	//! The class ID.
	/*!
    The panel's window class Identification. This is an enum.
	*/
	IdOptionsPanel m_classID;
};



/*! \class mgOptionsTreeCtrl
\brief The \c Edit | \c Options dialog box: the treelist control.

  This class lists in a treelist control all option's families: each
  item in the treelist has an associated \e option's \e panel that is
  displayed in the main dialog box.
  
  This class is very simple: it only has the constructor, the destructor.
  Events such he selection of an item in the treelist control are handled
  in the parent window  that is in the main dialog window.
	
  In order to add a new option's panel just add an item in the \b enum
  in the header file and add the item in the tree list control.
	  
  \sa mgOptDlg#OnItemSelected
*/
class mgOptionsTreeCtrl : public wxTreeCtrl
{
public:
	
	//! Constructor.
	/*!
	The ctor is used to add items in the treelist control. To add a new
	item, choose the correct parent \c itemID and use the \c AppendItem
	function.
	To add a top level item id you have to use the \c idRoot variable.
	*/
	mgOptionsTreeCtrl( wxWindow* parent );
	

	//! Destructor - it does nothing.
	virtual ~mgOptionsTreeCtrl();
	
	
private:
	DECLARE_CLASS( mgOptionsTreeCtrl )
	DECLARE_EVENT_TABLE()
};


#endif          // not defined DIALOGS_OPTTREECTRL_H

