///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
//! \file   SolveDlg.h
//! \brief  Defines the mgSolveDlg class.
//!
//! See SolveDlg.cpp for more info
///////////////////////////////////////////////////////////////////////


#ifndef SOLVEDLG_H
#define SOLVEDLG_H

// this class integrates with mgMathBox and mgMathWnd...
#include "mg/MathBoxWndUser.h"

// optimization for GCC compiler
#ifdef __GNUG__
#pragma interface "SolveDlg.h"
#endif


// mgSolvePanel defines
#define IDC_SOLVEPANEL_SOLVER_OPTION		mgSOLVEDLG_BASEID+1
#define IDC_SOLVEPANEL_SOLVE				mgSOLVEDLG_BASEID+2


//! This panel contains a list of the mcSolvers hold by MathCore.
//! The user is allowed to choose one of them, set its options and
class mgSolvePanel : public wxPanel, public mgMathBoxWndUser
{
protected:		// member variables

	// The list of mcSolvers.
	wxListBox *m_pListBox;

protected:		// functions

	// panel constructors
	void BuildCtrls();
	void BuildAll();

	// event handlers
	void OnSolve(wxCommandEvent &);
	void OnSolverOption(wxCommandEvent &);

	//! Updates the list of mcSolvers, enabling and disabling
	//! the mcSolvers that cannot be used...
	virtual void UpdateSolverList();

public:
	mgSolvePanel(
		wxWindow *parent, 
		mgMathWnd *pWnd, 
		mgMathBox *pBox, 
		wxWindowID id = -1, 
		const wxPoint& pos = wxDefaultPosition, 
		const wxSize& size = wxDefaultSize, 
		long style = wxTAB_TRAVERSAL, 
		const wxString& name = wxT("panel"));
	virtual ~mgSolvePanel() {}


private:
	DECLARE_CLASS( mgSolvePanel )
	DECLARE_EVENT_TABLE()
};


//! A simple dialog window containing a mgSolvePanel.
class mgSolveDlg : public wxDialog
{
protected:

	void OnPanelDismiss(wxCommandEvent &);

public:
	mgSolveDlg(
		wxWindow* parent, 
		mgMathWnd *pWnd, 
		mgMathBox *pBox, 
		wxWindowID id = -1, 
		const wxString& title = wxT("Choose the solver algorithm..."), 
		const wxPoint& pos = wxDefaultPosition, 
		const wxSize& size = wxDefaultSize, 
		long style = wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER, 
		const wxString& name = wxT("dialogBox"));
	virtual ~mgSolveDlg() {}

private:
	DECLARE_CLASS( mgSolveDlg )
	DECLARE_EVENT_TABLE()
};


#endif		// SOLVEDLG_H
