///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
//! \file   SpecialSymDlg.h
//! \brief  Defines the mgSpecialSymDlg class.
//!
//! See SpecialSymDlg.cpp for more info.
///////////////////////////////////////////////////////////////////////


#ifndef SPECIALSYM_H
#define SPECIALSYM_H

// both mgButtonListPanel & wxPaletteFrame classes are used...
#include "mg/PaletteDlg.h"
#ifdef mgUSE_PALETTEFRM
	#include <wx/palettefrm.h>
#endif


// optimization for GCC compiler
#ifdef __GNUG__
#pragma interface "SpecialSymDlg.h"
#endif


// the number of columns in the dialog
#define SPECIALSYMDLG_NUM_BUTTONS				6
#define SPECIALSYMDLG_COLUMNS					6
#define SPECIALSYMDLG_ROWS						1	//SPECIALSYMDLG_NUM_BUTTONS/GetColCount()

#define SPECIALSYMDLG_FONT_POINTSIZE			16

//! The buttons base ID.
#define IDC_SPECIALSYMDLG_BUTTONS				mgSPECIALSYMDLG_BASEID




//! Shows the user a palette which allows him to insert some special
//! symbols in the math data.
class mgSpecialSymPanel : public mgButtonListPanel
{
	//! The string containing the special symbols.
	static wxString strSymbols;

	//! The string containing the tooltips for the special symbols.
	static wxString strSymbolsTooltip[SPECIALSYMDLG_NUM_BUTTONS];

	void OnButtons( wxCommandEvent &event );
	void BuildButtons();

	wxString GetButtonLabel(int i)
	{ return strSymbols.GetChar(i); }
	
	wxString GetButtonTooltip(int i) 
	{ return strSymbolsTooltip[i]; }

public:

	//! Constructs this dialog. This function works as the standard
	//! wxWindow constructors, with just two new parameters:
	//! \param mathwnd The math window whose selected mathbox receives
	//!                the commands.
	//! \param mathbox The math box which receives the 
	//!                'create greek symbol' commands.
	mgSpecialSymPanel(
		wxWindow *parent,
		wxWindow *client,
		mgMathWnd *mathwnd,
		mgMathBox *mathbox,
		wxWindowID id = -1, 
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER);

	virtual ~mgSpecialSymPanel() {}
		
private:
	DECLARE_EVENT_TABLE()
};



//! A wxPaletteFrame-derived class which shows a mgSpecialSymPanel.
class mgSpecialSymPalette : public wxPaletteFrame
{
protected:

	//! Build a unique panel grouping the mgSmallGreekPanel and
	//! the mgCapitalGreekPanel panels.
	void Build(wxWindow *client, mgMathWnd *mathwnd, mgMathBox *mathbox);

public:

	mgSpecialSymPalette(
		wxMainFrame *parent,
		wxWindow *client,
		mgMathWnd *mathwnd,
		mgMathBox *mathbox,
		wxWindowID id = -1,
		const wxString &title = wxT("Special symbols"),
		const wxPoint &pos = wxDefaultPosition,
		const wxSize &size = wxDefaultSize,
		long style = wxPALETTEFRM_DEFAULT_STYLE,
		const wxString &name = wxT("mgSpecialSymPalette")) 
		: wxPaletteFrame(parent, id, title, pos, size, style, name) {

		// build everything...
		Build(client ? client : parent, mathwnd, mathbox);
	}

	virtual ~mgSpecialSymPalette() {}
};


#endif	// SPECIALSYM_H

