///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
//! \file   SymPropPanel.h
//! \brief  Defines the mgSymPropPanel class.
//!
//! See SymPropPanel.cpp for more info
///////////////////////////////////////////////////////////////////////



#ifndef SYMPROPPANEL_H
#define SYMPROPPANEL_H

// this dialog uses wxListCtrls & mcSymbolArrays
#include <wx/notebook.h>

// optimization for GCC compiler
#ifdef __GNUG__
#pragma interface "SymbolDlg.h"
#endif


// IDs
#define IDC_SYMPROP_ADD				SYMPROP_BASEID+1
#define IDC_SYMPROP_SET				SYMPROP_BASEID+2

//! The maximum number of digits (counting also the decimal point) which
//! can be typed in the value box of a constant.
#define SYMCONSTPROP_MAX_VALUE_LENGHT		20




//! The palette which allows the user to register parameters, unknowns
//! and constants in MathCore lists.
class mgSymPropPanel : public wxPanel
{
protected:		// member variables

	mgMathBox *m_pNameBox;
	mcSymbolProperties *m_pSymbol;

	mcFilter *mdata_pFilter;
	wxListCtrl *m_pList;

protected:		// functions

	virtual void BuildCtrls();
	virtual void AddSpecificCtrlsSizer(wxSizer *p) = 0;

	// event handlers
	void OnAddSymbolBtn(wxCommandEvent &event);
	void OnSetSymbolBtn(wxCommandEvent &event);

	virtual void OnSetSymbol() = 0;
	virtual void OnAddSymbol() = 0;

public:
	// constructors and destructors
	mgSymPropPanel(wxWindow *parent,
		wxWindowID id = -1, 
		const wxString &title = wxT("Properties"),
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = 0);
	virtual ~mgSymPropPanel();
	
	virtual void LinkWithSymbol(mcSymbolProperties *s);
	virtual void LinkWithList(wxListCtrl *p);
	virtual void BuildAll();

	virtual void Update();

	wxString GetName();
	
private:
	// used by wxWindow framework
	DECLARE_CLASS(mgSymPropPanel)
	DECLARE_EVENT_TABLE()
};



//! The panel which allows the user to modify the properties of the
//! variables.
class mgSymVarPropPanel : public mgSymPropPanel
{
protected:		// member variables

	mgMathBox *m_pRangeBox;

protected:		// functions

	void AddSpecificCtrlsSizer(wxSizer *p);

	void OnSetSymbol();
	void OnAddSymbol();

public:
	// constructors and destructors
	mgSymVarPropPanel(wxWindow *parent,
		wxWindowID id = -1, 
		const wxString &title = wxT("Properties"),
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = 0) : mgSymPropPanel(parent, id, title, pos, size, style) {}
	virtual ~mgSymVarPropPanel() {}
	
	
private:
	// used by wxWindow framework
	DECLARE_CLASS(mgSymVarPropPanel)
	DECLARE_EVENT_TABLE()
};



//! The panel which allows the user to modify the properties of the
//! constants.
class mgSymConstPropPanel : public mgSymPropPanel
{
protected:		// member variables

	//mgMathBox *m_pRangeBox;
	wxTextCtrl *m_pValue;
	wxString m_strValue;

protected:		// functions

	void AddSpecificCtrlsSizer(wxSizer *p);


	void OnSetSymbol();
	void OnAddSymbol();
	//void Update();

public:
	// constructors and destructors
	mgSymConstPropPanel(wxWindow *parent,
		wxWindowID id = -1, 
		const wxString &title = wxT("Properties"),
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = 0) : mgSymPropPanel(parent, id, title, pos, size, style) {}
	virtual ~mgSymConstPropPanel() {}
	
	//void LinkWithSymbol(mcSymbol *s);

	void Update();
	
private:
	// used by wxWindow framework
	DECLARE_CLASS(mgSymConstPropPanel)
	DECLARE_EVENT_TABLE()
};


#endif		// SYMPROPPANEL_H
