///////////////////////////////////////////////////////////////////////
// MathGUI = a WYSIWYG equation editor + a powerful math engine      //
// Copyright (C) 2003 by Francesco Montorsi                          //
//                                                                   //
// This library is free software; you can redistribute it and/or     //
// modify it under the terms of the GNU Lesser General Public        //
// License as published by the Free Software Foundation; either      //
// version 2.1 of the License, or (at your option) any later         //
// version.                                                          //
//                                                                   //
// This library is distributed in the hope that it will be useful,   //
// but WITHOUT ANY WARRANTY; without even the implied warranty of    //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      //
// GNU Lesser General Public License for more details.               //
//                                                                   //
// You should have received a copy of the GNU Lesser General Public  //
// License along with this program; if not, write to the Free        //
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   //
// MA 02111-1307, USA.                                               //
//                                                                   //
// For any comment, suggestion or feature request, please contact    //
// the administrator of the project at frm@users.sourceforge.net     //
//                                                                   //
///////////////////////////////////////////////////////////////////////
//! \file   SymbolDlg.h
//! \brief  Defines the mgSymbolPanel class.
//!
//! See SymbolDlg.cpp for more info
///////////////////////////////////////////////////////////////////////



#ifndef SYMBOLDLG_H
#define SYMBOLDLG_H

// this dialog uses wxListCtrls & mcSymbolArrays
#include <wx/notebook.h>
#include <wx/listctrl.h>
#include "mc/Symbol.h"
#include "mg/PaletteDlg.h"
#ifdef mgUSE_PALETTEFRM
	#include <wx/palettefrm.h>		// wxWidgets' extension
#endif


// optimization for GCC compiler
#ifdef __GNUG__
#pragma interface "SymbolDlg.h"
#endif


// IDs used in this dialog
#define IDC_SYMBOLDLG_LIST					mgSYMBOLDLG_BASEID+1
#define IDC_SYMBOLDLG_DELETE				mgSYMBOLDLG_BASEID+3

#define IDC_SYMLISTPAGE_LISTCTRL			mgSYMBOLDLG_BASEID+4

#define SYMPROP_BASEID						mgSYMBOLDLG_BASEID+5

// forward declarations
class mgSymPropPanel;


//! A panel designed to be used in a wxNotebookPage widget.
//!
//! VERY IMPORTANT: the base class cannot be wxNotebookPage because
//!                 it seems that sizers do not work inside it.
//!                 Instead (like all wxWidgets notebook examples),
//!                 wxPanel will be used.
class mgSymListPage : public wxPanel
{
protected:		// member variables

	mgSymPropPanel *m_pPropPanel;
	mcSymbolArray *m_pArray;

	wxListCtrl *m_pList;
	//wxWindow *m_pList;


protected:		// functions

	virtual void BuildCtrls();
	virtual void BuildAll();


	// event handlers
	void OnSelectionChanged(wxListEvent &);

public:

	mgSymListPage(wxWindow *parent,
		mgSymPropPanel *prop,
		mcSymbolArray *arr,
		wxWindowID id = -1, 
		const wxString &title = wxT("Symbols"),
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = 0);

	virtual ~mgSymListPage() {}

	mgSymPropPanel *GetLinkedPropPanel() {
		return m_pPropPanel;
	}

private:
	DECLARE_CLASS(mgSymListPage)
	DECLARE_EVENT_TABLE()
};




//! The palette which allows the user to register parameters, unknowns
//! and constants in mcSymbol arrays.
class mgSymbolPanel : public wxPanel, public mgMathBoxWndUser
{
protected:		// member variables

	//! The notebook containing the pages with the lists of the
	//! registered symbols...
	wxNotebook *m_pList;

	//! The list where all the symbols are stored.
	//wxListCtrl *m_pList;
	wxStaticBoxSizer *m_pPropertySizer;

	//! The text control which contains the name of the symbol to add.
	wxTextCtrl *m_pText;

	//! The array which is modified by this dialog.
	mcSymbolArray *m_pArray;


protected:		// functions

	void BuildAll();
	void BuildCtrls();

	int GetBaseID() const		{ return mgSYMBOLDLG_BASEID; }

	// event handlers
	void OnDeleteSymbol( wxCommandEvent &event );
	void OnPageChanged(wxNotebookEvent &ev);


	int GetDefaultWidth() { return 100; }
	int GetDefaultHeight() { return 100;}

	wxString GetButtonLabel(int n) { return wxT(""); }
	wxString GetButtonTooltip(int n) { return wxT(""); }


	int GetColCount() const		 { return 1; }
	int GetRowCount() const		 { return 1; }


public:
	// constructors and destructors
	mgSymbolPanel(
		wxWindow *parent,
		mgMathWnd *mathwnd,
		mgMathBox *mathbox,
		mcSymbolArray *,
		wxWindowID id = -1, 
		const wxString &title = wxT("Symbols"),
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER);
	virtual ~mgSymbolPanel();
	


	void Sync();
	void AddDefaultLists();


private:
	// used by wxWindow framework
	DECLARE_CLASS(mgSymbolPanel)
	DECLARE_EVENT_TABLE()
};


//! A wxPaletteFrame-derived class which shows a mgSymbolPanel.
class mgSymbolPalette : public wxPaletteFrame
{
public:

#ifndef mgUSE_PALETTEFRM
	wxPanel *m_pPanel;

	// a fake function
	void SetSizeHintsUsingClientHints() {}
#endif

public:

	mgSymbolPalette(
		wxMainFrame *parent,
		wxWindow *client,
		mgMathWnd *mathwnd,
		mgMathBox *mathbox,
		mcSymbolArray *arr,
		wxWindowID id = -1,
		const wxString &title = wxT("Symbols"),
		const wxPoint &pos = wxDefaultPosition,
		const wxSize &size = wxDefaultSize,
		long style = wxPALETTEFRM_DEFAULT_STYLE,
		const wxString &name = wxT("mgSymbolPalette"));

	virtual ~mgSymbolPalette() {}


	//! Returns the mgSymbolPanel which is contained.
	mgSymbolPanel *GetPanel();

};


#endif		// SYMBOLDLG_H

