/////////////////////////////////////////////////////////////////////////////
// Name:        wx/clrbtn.h
// Purpose:     wxColourButton
// Author:      Francesco Montorsi
// Modified by:
// Created:     27/1/04
// RCS-ID:      $Id:     1.00 2004/01/27 frm
// Copyright:   (c) Francesco Montorsi
// Licence:     wxWidgets licence
/////////////////////////////////////////////////////////////////////////////


#ifndef _WX_COLOURBUTTON_H
#define _WX_COLOURBUTTON_H

// optimization for GCC
#if defined(__GNUG__) && !defined(__APPLE__)
#pragma interface "clrbtn.h"
#endif

// wxWidgets headers
#include "wx/bmpbuttn.h"
#include "wx/colordlg.h"		// for wxColourDialog


// just to allow both type of naming...
#define wxColorButton		wxColourButton



// A special type of wxBitmapButton which uses as label a bitmap
// containing a solid color.
// When the user clicks on the button (this class auto-handles
// its clicks), a wxColourDialog is shown, which allows the user
// to choose a color. If wxColourDialog::ShowModal returns wxID_OK, 
// then the bitmap label is updated.
class wxColourButton : public wxBitmapButton
{
protected:

	// The bitmap containing the solid color set for this button.
	wxBitmap *m_pLabel;

	// The current color contained in the bitmap label.
	wxColour m_colCurrent;

	// Handles the button click showing to the user a wxColourDialog
	// and eventually, updating the color shown as label.
	void OnClick(wxCommandEvent &ev);

	// Handles the size events, forcing the bitmap reconstruction.
	void OnResize(wxSizeEvent &);

public:

	// The constructor.
	wxColourButton(
		wxWindow* parent, 
		wxWindowID id, 
		const wxColour clr, 
#ifdef __WXGTK__
		int additionalmarginx = 25,
		int additionalmarginy = 25,
#else
		int additionalmarginx = 2,
		int additionalmarginy = 1,
#endif
		const wxPoint& pos = wxDefaultPosition, 
		const wxSize& size = wxDefaultSize, 
		long style = wxBU_AUTODRAW | wxSUNKEN_BORDER, 
		const wxValidator& validator = wxDefaultValidator, 
		const wxString& name = wxT("button")) :
		
		wxBitmapButton(parent, id, wxNullBitmap, pos, 
			size, style, validator, name), m_pLabel(NULL) {

			// the bitmap we gave to wxBitmapButton constructor
			// is empty... update it
			SetColour(clr);

			// m_marginX and Y are returned by GetMarginX and Y...
			m_marginX += additionalmarginx;
			m_marginY += additionalmarginy;
	}

	virtual ~wxColourButton() { if (m_pLabel) delete m_pLabel; }


	// Changes the colour displayed on the label.
	void SetColour(const wxColour newcol);

	// Retrieves the color displayed on the label.
	wxColour GetColour() { return m_colCurrent;	}


private:
	DECLARE_EVENT_TABLE()
};

#endif		// _WX_COLOURBUTTON_H

